==> fengoffice_1.7.5.zip: fengoffice/language/en_us/fields.php <==
<?php

return array(

	// Company fields
	'field Companies name' => 'Name',
	'field Companies address' => 'Address',
	'field Companies address2' => 'Address 2',
	'field Companies city' => 'City',
	'field Companies state' => 'State',
	'field Companies zipcode' => 'Zipcode',
	'field Companies country' => 'Country',
	'field Companies phone_number' => 'Phone',
	'field Companies fax_number' => 'Fax',
	'field Companies email' => 'Email address',
	'field Companies homepage' => 'Homepage',
	'field Companies notes' => 'Notes',
	'field Companies homepage' => 'Homepage',
	'field Companies created_on' => 'Created on',
	'field Companies updated_on' => 'Updated on',
	'field Companies created_by_id' => 'Created by',
	'field Companies updated_by_id' => 'Updated by',
	'field Companies archived_on' => 'Archived on',
	'field Companies archived_by_id' => 'Archived by',

	// Contact fields
	'field Contacts company_id' => 'Company',
	'field Contacts firstname' => 'First name',
	'field Contacts lastname' => 'Last name',
	'field Contacts email' => 'Email address',
	'field Contacts w_web_page' => 'Work website', 
	'field Contacts w_address' => 'Work address',
	'field Contacts w_city' => 'Work city',
	'field Contacts w_state' => 'Work state',
	'field Contacts w_zipcode' => 'Work zipcode',
	'field Contacts w_country' => 'Work country',
	'field Contacts w_phone_number' => 'Work phone',
	'field Contacts w_phone_number2' => 'Work phone 2',
	'field Contacts w_fax_number' => 'Work fax',
	'field Contacts w_assistant_number' => 'Work assistant',
	'field Contacts w_callback_number' => 'Work callback',

	'field Contacts h_web_page' => 'Home website',
	'field Contacts h_address' => 'Home address',
	'field Contacts h_city' => 'Home city',
	'field Contacts h_state' => 'Home state',
	'field Contacts h_zipcode' => 'Home zipcode',
	'field Contacts h_country' => 'Home country',
	'field Contacts h_phone_number' => 'Home phone',
	'field Contacts h_phone_number2' => 'Home phone 2',
	'field Contacts h_fax_number' => 'Home fax',
	'field Contacts h_mobile_number' => 'Home mobile',
	'field Contacts h_pager_number' => 'Home pager',

	'field Contacts o_web_page' => 'Other website',
	'field Contacts o_address' => 'Other address',
	'field Contacts o_city' => 'Other city',
	'field Contacts o_state' => 'Other state',
	'field Contacts o_zipcode' => 'Other zipcode',
	'field Contacts o_country' => 'Other country',
	'field Contacts o_phone_number' => 'Other phone',
	'field Contacts o_phone_number2' => 'Other phone 2',
	'field Contacts o_fax_number' => 'Other fax',
	'field Contacts o_birthday' => 'Birthday',
	'field Contacts email2' => 'Email address 2',
	'field Contacts email3' => 'Email address 3',
	'field Contacts job_title' => 'Job title',
	'field Contacts department' => 'Department', 
	'field Contacts middlename' => 'Middle name', 
	'field Contacts notes' => 'Notes',
	'field Contacts created_on' => 'Created on',
	'field Contacts updated_on' => 'Updated on',
	'field Contacts created_by_id' => 'Created by',
	'field Contacts updated_by_id' => 'Updated by',
	'field Contacts archived_on' => 'Archived on',
	'field Contacts archived_by_id' => 'Archived by',

	// Email fields
    'field MailContents from' => 'From',
    'field MailContents from_name' => 'From name',
    'field MailContents to'  => 'To',
    'field MailContents date' => 'Date',
    'field MailContents sent_date' => 'Sent date',
	'field MailContents received_date' => 'Received date',
    'field MailContents subject' => 'Subject',
    'field MailContents content' => 'Content',
	'field MailContents body' => 'Body',
    'field MailContents body_plain' => 'Body plain',
    'field MailContents body_html' => 'Body HTML',
    'field MailContents has_attachments' => 'Has attachments', 
    'field MailContents size' => 'Size', 
    'field MailContents state' => 'State', 
    'field MailContents is_deleted' => 'Is deleted', 
    'field MailContents is_shared' => 'Is shared',
	'field MailContents imap_folder_name' => 'IMAP Folder name',
	'field MailContents account_email' => 'Account email',
	'field MailContents created_on' => 'Created on',
	'field MailContents created_by_id' => 'Created by',
	'field MailContents updated_by_id' => 'Updated by',
	'field MailContents cc' => 'CC',
	'field MailContents bcc' => 'BCC',
	'field MailContents archived_on' => 'Archived on',
	'field MailContents archived_by_id' => 'Archived by',
	'field MailContents sync' => 'Synchronized',

	// Event fields
    'field ProjectEvents duration' => 'End',
    'field ProjectEvents start' => 'Start',
    'field ProjectEvents subject' => 'Subject',
    'field ProjectEvents repeat_forever'=> 'Repeat forever',
    'field ProjectEvents description' => 'Description',
    'field ProjectEvents private' => 'Private',
    'field ProjectEvents repeat_end' => 'Repeat end',
    'field ProjectEvents repeat_num' => 'Repeat number',
    'field ProjectEvents repeat_d' => 'Repeat day',
    'field ProjectEvents repeat_m' => 'Repeat month',
    'field ProjectEvents repeat_y' => 'Repeat year',
    'field ProjectEvents repeat_h' => 'Repeat hour',
	'field ProjectEvents created_on' => 'Created on',
	'field ProjectEvents updated_on' => 'Updated on',
	'field ProjectEvents created_by_id' => 'Created by',
	'field ProjectEvents updated_by_id' => 'Updated by',
	'field ProjectEvents archived_on' => 'Archived on',
	'field ProjectEvents archived_by_id' => 'Archived by',
	'field ProjectEvents repeat_dow' => 'Repeat day of week',
	'field ProjectEvents repeat_mjump' => 'Repeat month jump',
	'field ProjectEvents repeat_wnum' => 'Repeat week number',

	// File fields
	'field ProjectFiles filename' => 'Filename', 
    'field ProjectFiles description' => 'Description', 
    'field ProjectFiles is_important' => 'Is important', 
    'field ProjectFiles is_locked' => 'Is locked', 
    'field ProjectFiles is_visible' => 'Is visible', 
    'field ProjectFiles expiration_time' => 'Expiration time', 
    'field ProjectFiles comments_enabled' => 'Comments enabled', 
    'field ProjectFiles anonymous_comments_enabled' => 'Anonymous comments enabled', 
	'field ProjectFiles url' => 'Url',
	'field ProjectFiles created_on' => 'Created on',
	'field ProjectFiles updated_on' => 'Updated on',
	'field ProjectFiles checked_out_on' => 'Checked out on',
	'field ProjectFiles created_by_id' => 'Created by',
	'field ProjectFiles updated_by_id' => 'Updated by',
	'field ProjectFiles archived_on' => 'Archived on',
	'field ProjectFiles archived_by_id' => 'Archived by',
	'field ProjectFileRevisions filecontent' => 'File content',

	// Milestone fields
    'field ProjectMilestones name' => 'Name',
    'field ProjectMilestones description' => 'Description',
    'field ProjectMilestones due_date' => 'Due date',
    'field ProjectMilestones completed_on' => 'Completed on',
	'field ProjectMilestones is_template' => 'Is template',
	'field ProjectMilestones created_on' => 'Created on',
	'field ProjectMilestones updated_on' => 'Updated on',
	'field ProjectMilestones created_by_id' => 'Created by',
	'field ProjectMilestones updated_by_id' => 'Updated by',
	'field ProjectMilestones assigned_to_company_id' => 'Assigned to company',		
	'field ProjectMilestones assigned_to_user_id' => 'Assigned to user',
	'field ProjectMilestones archived_on' => 'Archived on',
	'field ProjectMilestones archived_by_id' => 'Archived by',

	// Message fields
	'field ProjectMessages title' => 'Title', 
    'field ProjectMessages text' => 'Text', 
    'field ProjectMessages additional_text' => 'Additional text', 
    'field ProjectMessages is_important' => 'Is important', 
    'field ProjectMessages comments_enabled' => 'Comments enabled', 
    'field ProjectMessages anonymous_comments_enabled' => 'Anonymous comments enabled', 
	'field ProjectMessages created_on' => 'Created on',
	'field ProjectMessages updated_on' => 'Updated on',
	'field ProjectMessages created_by_id' => 'Created by',
	'field ProjectMessages updated_by_id' => 'Updated by',
	'field ProjectMessages milestone_id' => 'Milestone',
	'field ProjectMessages archived_on' => 'Archived on',
	'field ProjectMessages archived_by_id' => 'Archived by',

	// Task fields
	'field ProjectTasks text' => 'Text',
	'field ProjectTasks completed_on' => 'Completed on', 
	'field ProjectTasks due_date' => 'Due date',
	'field ProjectTasks start_date' => 'Start date',
	'field ProjectTasks created_on' => 'Created on',
	'field ProjectTasks updated_on' => 'Updated on',
	'field ProjectTasks order' => 'Order',
	'field ProjectTasks title' => 'Title', 
	'field ProjectTasks started_on' => 'Started on',
	'field ProjectTasks priority' => 'Priority', 
    'field ProjectTasks assigned_on' => 'Assigned on',
	'field ProjectTasks time_estimate' => 'Time estimate',
	'field ProjectTasks is_template' => 'Is template',
	'field ProjectTasks created_by_id' => 'Created by',
	'field ProjectTasks updated_by_id' => 'Updated by',
	'field ProjectTasks milestone_id' => 'Milestone',
	'field ProjectTasks assigned_to_company_id' => 'Assigned to company',		
	'field ProjectTasks assigned_to_user_id' => 'Assigned to user',
	'field ProjectTasks completed_by_id' => 'Completed by',
	'field ProjectTasks archived_on' => 'Archived on',
	'field ProjectTasks archived_by_id' => 'Archived by',
	'field ProjectTasks repeat_by' => 'Repeat by',
	'field ProjectTasks repeat_end' => 'Repeat end',
    'field ProjectTasks repeat_num' => 'Repeat number',
	'field ProjectTasks repeat_forever' => 'Repeat forever',
    'field ProjectTasks repeat_d' => 'Repeat day',
    'field ProjectTasks repeat_m' => 'Repeat month',
    'field ProjectTasks repeat_y' => 'Repeat year',
    'field ProjectTasks object_subtype' => 'Object subtype',
	'field ProjectTasks state' => 'Status',
	'field ProjectTasks status' => 'Status',

	// User fields
    'field Users username' => 'Username', 
    'field Users email' => 'Email',
	'field Users type' => 'Type', 
    'field Users display_name' => 'Display name', 
    'field Users title' => 'Title', 
    'field Users created_on' => 'Created on', 
    'field Users updated_on' => 'Updated on', 
    'field Users last_login' => 'Last login', 
    'field Users last_visit' => 'Last visit', 
    'field Users last_activity' => 'Last activity', 
    'field Users can_edit_company_data' => 'Can edit owner company data',
    'field Users can_manage_workspaces'=> 'Can manage workspaces',
    'field Users can_manage_security' => 'Can manage security',
    'field Users can_manage_configuration' => 'Can manage configuration', 
    'field Users auto_assign' => 'Auto assign', 
    'field Users can_manage_contacts' => 'Can manage all contacts',
    'field Users can_manage_templates' => 'Can manage templates',
	'field Users can_manage_reports'=> 'Can manage reports',
	'field Users can_manage_time'=> 'Can manage time',
	'field Users can_add_mail_accounts'=> 'Can add email accounts',
	'field Users created_by_id' => 'Created by',
	'field Users updated_by_id' => 'Updated by',
	'field Users company_id' => 'Company',
	'field Users archived_on' => 'Archived on',
	'field Users archived_by_id' => 'Archived by',

	// Webpage fields
    'field ProjectWebpages url' => 'Url', 
    'field ProjectWebpages title' => 'Title', 
    'field ProjectWebpages description' => 'Description', 
    'field ProjectWebpages created_on' => 'Created on',
    'field ProjectWebpages updated_on' => 'Updated on',
	'field ProjectWebpages created_by_id' => 'Created by',
	'field ProjectWebpages updated_by_id' => 'Updated by',
	'field ProjectWebpages archived_on' => 'Archived on',
	'field ProjectWebpages archived_by_id' => 'Archived by',

	// Project fields
	'field Projects name' => 'Name', 
    'field Projects description' => 'Description', 
    'field Projects show_description_in_overview' => 'Show description in overview', 
    'field Projects completed_on' => 'Completed on', 
    'field Projects created_on' => 'Created on', 
    'field Projects updated_on' => 'Updated on',
	'field Projects created_by_id' => 'Created by', 
    'field Projects updated_by_id' => 'Updated by',
	'field Projects completed_by_id' => 'Completed by',
	'field Projects archived_on' => 'Archived on',
	'field Projects archived_by_id' => 'Archived by',
);

?>

==> fengoffice_2.0.0.zip: fengoffice/language/en_us/fields.php <==
<?php

return array(

	// Company fields
	'field Companies name' => 'Name',
	'field Companies address' => 'Address',
	'field Companies address2' => 'Address 2',
	'field Companies city' => 'City',
	'field Companies state' => 'State',
	'field Companies zipcode' => 'Zipcode',
	'field Companies country' => 'Country',
	'field Companies phone_number' => 'Phone',
	'field Companies fax_number' => 'Fax',
	'field Companies email' => 'Email address',
	'field Companies homepage' => 'Homepage',
	'field Companies notes' => 'Notes',
	'field Companies homepage' => 'Homepage',
	'field Companies created_on' => 'Created on',
	'field Companies updated_on' => 'Updated on',
	'field Companies created_by_id' => 'Created by',
	'field Companies updated_by_id' => 'Updated by',
	'field Companies archived_on' => 'Archived on',
	'field Companies archived_by_id' => 'Archived by',

	// Contact fields
	'field Contacts company_id' => 'Company',
	'field Contacts firstname' => 'First name',
	'field Contacts lastname' => 'Last name',
	'field Contacts email' => 'Email address',
	'field Contacts w_web_page' => 'Work website', 
	'field Contacts w_address' => 'Work address',
	'field Contacts w_city' => 'Work city',
	'field Contacts w_state' => 'Work state',
	'field Contacts w_zipcode' => 'Work zipcode',
	'field Contacts w_country' => 'Work country',
	'field Contacts w_phone_number' => 'Work phone',
	'field Contacts w_phone_number2' => 'Work phone 2',
	'field Contacts w_fax_number' => 'Work fax',
	'field Contacts w_assistant_number' => 'Work assistant',
	'field Contacts w_callback_number' => 'Work callback',

	'field Contacts h_web_page' => 'Home website',
	'field Contacts h_address' => 'Home address',
	'field Contacts h_city' => 'Home city',
	'field Contacts h_state' => 'Home state',
	'field Contacts h_zipcode' => 'Home zipcode',
	'field Contacts h_country' => 'Home country',
	'field Contacts h_phone_number' => 'Home phone',
	'field Contacts h_phone_number2' => 'Home phone 2',
	'field Contacts h_fax_number' => 'Home fax',
	'field Contacts h_mobile_number' => 'Home mobile',
	'field Contacts h_pager_number' => 'Home pager',

	'field Contacts o_web_page' => 'Other website',
	'field Contacts o_address' => 'Other address',
	'field Contacts o_city' => 'Other city',
	'field Contacts o_state' => 'Other state',
	'field Contacts o_zipcode' => 'Other zipcode',
	'field Contacts o_country' => 'Other country',
	'field Contacts o_phone_number' => 'Other phone',
	'field Contacts o_phone_number2' => 'Other phone 2',
	'field Contacts o_fax_number' => 'Other fax',
	'field Contacts o_birthday' => 'Birthday',
	'field Contacts email2' => 'Email address 2',
	'field Contacts email3' => 'Email address 3',
	'field Contacts job_title' => 'Job title',
	'field Contacts department' => 'Department', 
	'field Contacts middlename' => 'Middle name', 
	'field Contacts notes' => 'Notes',
	'field Contacts created_on' => 'Created on',
	'field Contacts updated_on' => 'Updated on',
	'field Contacts created_by_id' => 'Created by',
	'field Contacts updated_by_id' => 'Updated by',
	'field Contacts archived_on' => 'Archived on',
	'field Contacts archived_by_id' => 'Archived by',
	'field Contacts birthday' => 'Birthday',
	'field Contacts disabled' => 'Is disabled',
	'field Contacts display_name' => 'Display Name',
	'field Contacts first_name' => 'First Name',
	'field Contacts is_company' => 'Is Company',
	'field Contacts last_activity' => 'Last activity',
	'field Contacts last_login' => 'Last login',
	'field Contacts last_visit' => 'Last visit',
	'field Contacts surname' => 'Surname',
	'field Contacts username' => 'Username',

	// Email fields
    'field MailContents from' => 'From',
    'field MailContents from_name' => 'From name',
    'field MailContents to'  => 'To',
    'field MailContents date' => 'Date',
    'field MailContents sent_date' => 'Sent date',
	'field MailContents received_date' => 'Received date',
    'field MailContents subject' => 'Subject',
    'field MailContents content' => 'Content',
	'field MailContents body' => 'Body',
    'field MailContents body_plain' => 'Body plain',
    'field MailContents body_html' => 'Body HTML',
    'field MailContents has_attachments' => 'Has attachments', 
    'field MailContents size' => 'Size', 
    'field MailContents state' => 'State', 
    'field MailContents is_deleted' => 'Is deleted', 
    'field MailContents is_shared' => 'Is shared',
	'field MailContents imap_folder_name' => 'IMAP Folder name',
	'field MailContents account_email' => 'Account email',
	'field MailContents created_on' => 'Created on',
	'field MailContents created_by_id' => 'Created by',
	'field MailContents updated_by_id' => 'Updated by',
	'field MailContents cc' => 'CC',
	'field MailContents bcc' => 'BCC',
	'field MailContents archived_on' => 'Archived on',
	'field MailContents archived_by_id' => 'Archived by',
	'field MailContents sync' => 'Synchronized',

	// Event fields
    'field ProjectEvents duration' => 'End',
    'field ProjectEvents start' => 'Start',
    'field ProjectEvents subject' => 'Subject',
    'field ProjectEvents repeat_forever'=> 'Repeat forever',
    'field ProjectEvents description' => 'Description',
    'field ProjectEvents private' => 'Private',
    'field ProjectEvents repeat_end' => 'Repeat end',
    'field ProjectEvents repeat_num' => 'Repeat number',
    'field ProjectEvents repeat_d' => 'Repeat day',
    'field ProjectEvents repeat_m' => 'Repeat month',
    'field ProjectEvents repeat_y' => 'Repeat year',
    'field ProjectEvents repeat_h' => 'Repeat hour',
	'field ProjectEvents created_on' => 'Created on',
	'field ProjectEvents updated_on' => 'Updated on',
	'field ProjectEvents created_by_id' => 'Created by',
	'field ProjectEvents updated_by_id' => 'Updated by',
	'field ProjectEvents archived_on' => 'Archived on',
	'field ProjectEvents archived_by_id' => 'Archived by',
	'field ProjectEvents repeat_dow' => 'Repeat day of week',
	'field ProjectEvents repeat_mjump' => 'Repeat month jump',
	'field ProjectEvents repeat_wnum' => 'Repeat week number',

	// File fields
	'field ProjectFiles filename' => 'Filename', 
    'field ProjectFiles description' => 'Description', 
    'field ProjectFiles is_important' => 'Is important', 
    'field ProjectFiles is_locked' => 'Is locked', 
    'field ProjectFiles is_visible' => 'Is visible', 
    'field ProjectFiles expiration_time' => 'Expiration time', 
    'field ProjectFiles comments_enabled' => 'Comments enabled', 
    'field ProjectFiles anonymous_comments_enabled' => 'Anonymous comments enabled', 
	'field ProjectFiles url' => 'Url',
	'field ProjectFiles created_on' => 'Created on',
	'field ProjectFiles updated_on' => 'Updated on',
	'field ProjectFiles checked_out_on' => 'Checked out on',
	'field ProjectFiles created_by_id' => 'Created by',
	'field ProjectFiles updated_by_id' => 'Updated by',
	'field ProjectFiles archived_on' => 'Archived on',
	'field ProjectFiles archived_by_id' => 'Archived by',
	'field ProjectFileRevisions filecontent' => 'File content',

	// Milestone fields
    'field ProjectMilestones name' => 'Name',
    'field ProjectMilestones description' => 'Description',
    'field ProjectMilestones due_date' => 'Due date',
    'field ProjectMilestones completed_on' => 'Completed on',
	'field ProjectMilestones is_template' => 'Is template',
	'field ProjectMilestones created_on' => 'Created on',
	'field ProjectMilestones updated_on' => 'Updated on',
	'field ProjectMilestones created_by_id' => 'Created by',
	'field ProjectMilestones updated_by_id' => 'Updated by',
	'field ProjectMilestones assigned_to_company_id' => 'Assigned to company',		
	'field ProjectMilestones assigned_to_user_id' => 'Assigned to user',
	'field ProjectMilestones archived_on' => 'Archived on',
	'field ProjectMilestones archived_by_id' => 'Archived by',
	'field ProjectMilestones assigned_to_contact_id' => 'Assigned to',
	'field ProjectMilestones is_urgent' => 'Is urgent',

	// Message fields
	'field ProjectMessages title' => 'Title', 
    'field ProjectMessages text' => 'Text', 
    'field ProjectMessages additional_text' => 'Additional text', 
    'field ProjectMessages is_important' => 'Is important', 
    'field ProjectMessages comments_enabled' => 'Comments enabled', 
    'field ProjectMessages anonymous_comments_enabled' => 'Anonymous comments enabled', 
	'field ProjectMessages created_on' => 'Created on',
	'field ProjectMessages updated_on' => 'Updated on',
	'field ProjectMessages created_by_id' => 'Created by',
	'field ProjectMessages updated_by_id' => 'Updated by',
	'field ProjectMessages milestone_id' => 'Milestone',
	'field ProjectMessages archived_on' => 'Archived on',
	'field ProjectMessages archived_by_id' => 'Archived by',

	// Task fields
	'field ProjectTasks text' => 'Text',
	'field ProjectTasks completed_on' => 'Completed on', 
	'field ProjectTasks due_date' => 'Due date',
	'field ProjectTasks start_date' => 'Start date',
	'field ProjectTasks created_on' => 'Created on',
	'field ProjectTasks updated_on' => 'Updated on',
	'field ProjectTasks order' => 'Order',
	'field ProjectTasks title' => 'Title', 
	'field ProjectTasks started_on' => 'Started on',
	'field ProjectTasks priority' => 'Priority', 
    'field ProjectTasks assigned_on' => 'Assigned on',
	'field ProjectTasks time_estimate' => 'Time estimate',
	'field ProjectTasks is_template' => 'Is template',
	'field ProjectTasks created_by_id' => 'Created by',
	'field ProjectTasks updated_by_id' => 'Updated by',
	'field ProjectTasks milestone_id' => 'Milestone',
	'field ProjectTasks assigned_to_contact_id' => 'Assigned to',
	'field ProjectTasks completed_by_id' => 'Completed by',
	'field ProjectTasks archived_on' => 'Archived on',
	'field ProjectTasks archived_by_id' => 'Archived by',
	'field ProjectTasks repeat_by' => 'Repeat by',
	'field ProjectTasks repeat_end' => 'Repeat end',
    'field ProjectTasks repeat_num' => 'Repeat number',
	'field ProjectTasks repeat_forever' => 'Repeat forever',
    'field ProjectTasks repeat_d' => 'Repeat day',
    'field ProjectTasks repeat_m' => 'Repeat month',
    'field ProjectTasks repeat_y' => 'Repeat year',
    'field ProjectTasks object_subtype' => 'Object subtype',
	'field ProjectTasks percent_completed' => 'Percent completed',

	// User fields
    'field Users username' => 'Username', 
    'field Users email' => 'Email',
	'field Users type' => 'Type', 
    'field Users display_name' => 'Display name', 
    'field Users title' => 'Title', 
    'field Users created_on' => 'Created on', 
    'field Users updated_on' => 'Updated on', 
    'field Users last_login' => 'Last login', 
    'field Users last_visit' => 'Last visit', 
    'field Users last_activity' => 'Last activity', 
    'field Users can_edit_company_data' => 'Can edit owner company data',
    'field Users can_manage_workspaces'=> 'Can manage workspaces',
    'field Users can_manage_security' => 'Can manage security',
    'field Users can_manage_configuration' => 'Can manage configuration', 
    'field Users auto_assign' => 'Auto assign', 
    'field Users can_manage_contacts' => 'Can manage all people',
    'field Users can_manage_templates' => 'Can manage templates',
	'field Users can_manage_reports'=> 'Can manage reports',
	'field Users can_manage_time'=> 'Can manage time',
	'field Users can_add_mail_accounts'=> 'Can add email accounts',
	'field Users created_by_id' => 'Created by',
	'field Users updated_by_id' => 'Updated by',
	'field Users company_id' => 'Company',
	'field Users archived_on' => 'Archived on',
	'field Users archived_by_id' => 'Archived by',

	// Webpage fields
    'field ProjectWebpages url' => 'Url', 
    'field ProjectWebpages title' => 'Title', 
    'field ProjectWebpages description' => 'Description', 
    'field ProjectWebpages created_on' => 'Created on',
    'field ProjectWebpages updated_on' => 'Updated on',
	'field ProjectWebpages created_by_id' => 'Created by',
	'field ProjectWebpages updated_by_id' => 'Updated by',
	'field ProjectWebpages archived_on' => 'Archived on',
	'field ProjectWebpages archived_by_id' => 'Archived by',

	// Project fields
	'field Projects name' => 'Name', 
    'field Projects description' => 'Description', 
    'field Projects show_description_in_overview' => 'Show description in overview', 
    'field Projects completed_on' => 'Completed on', 
    'field Projects created_on' => 'Created on', 
    'field Projects updated_on' => 'Updated on',
	'field Projects created_by_id' => 'Created by', 
    'field Projects updated_by_id' => 'Updated by',
	'field Projects completed_by_id' => 'Completed by',
	'field Projects archived_on' => 'Archived on',
	'field Projects archived_by_id' => 'Archived by',
);

?>
